Detailed API documentation
==========================

.. automodapi:: pygaia.astrometry.constants
    :no-inheritance-diagram:
    
.. automodapi:: pygaia.astrometry.coordinates
    :no-inheritance-diagram:
    
.. automodapi:: pygaia.astrometry.vectorastrometry
    :no-inheritance-diagram:
    
.. automodapi:: pygaia.errors.astrometric
    :no-inheritance-diagram:

.. automodapi:: pygaia.errors.photometric
    :no-inheritance-diagram:

.. automodapi:: pygaia.errors.spectroscopic
    :no-inheritance-diagram:

.. automodapi:: pygaia.errors.utils
    :no-inheritance-diagram:

.. automodapi:: pygaia.photometry.transformations
    :no-inheritance-diagram:

.. automodapi:: pygaia.photometry.utils
    :no-inheritance-diagram:

.. automodapi:: pygaia.plot.sky
    :no-inheritance-diagram:
